@@ -1,14 +1,14 @@
 
 import os
 
-from lily_assistant.config import Config
+from lily.shared import get_lily_path
 import djclick as click
 
 
 @click.command()
 def command():
 
-    examples_path = os.path.join(Config.get_lily_path(), 'examples.json')
+    examples_path = os.path.join(get_lily_path(), 'examples.json')
 
     try:
         os.remove(examples_path)
