@@ -11,13 +11,6 @@ from .logger import Logger
 logger = Logger()
 
 
-"""
-Quick hack to force lily_assistant to see correct encoding locales.
-
-Please keep in mind that those encoding will live only in the process
-spawned by lily_assistant and will not contaminate your global namespace.
-
-"""
 if not os.environ.get('LC_ALL'):  # pragma: no cover
     os.environ['LC_ALL'] = 'en_US.utf-8'
 
@@ -28,8 +21,6 @@ if not os.environ.get('LANG'):  # pragma: no cover
 
 @click.group()
 def cli():
-    """Expose multiple commands allowing one to work with lily_assistant."""
-
     pass
 
 
@@ -48,12 +39,9 @@ def init(src_dir):
 
     """
 
-    # -- check that init for lily_assistant was executed too
     if not os.path.exists(os.path.join(os.getcwd(), '.lily', 'config.json')):
         raise click.ClickException(textwrap.dedent('''
-            Please install `lily_assistant` and run
-            `lily_assistant init <src_dir>` before running
-            `lily init <src_dir>`
+            Please run `lily init <src_dir>`
         '''))
 
     Copier().copy(src_dir)
